@@ -35,8 +35,30 @@ use warnings;
 use base qw{ PPIx::Regexp::Structure };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
+use PPIx::Regexp::Util;
 
-our $VERSION = '0.070';
+our $VERSION = '0.084';
+
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    my $self = $class->SUPER::__new( $content, %arg );
+
+    defined $arg{error}
+	and $self->{explanation} = $self->{error} = $arg{error};
+
+    defined $arg{explanation}
+	and $self->{explanation} = $arg{explanation};
+
+    return $self;
+}
+
+sub explain {
+    my ( $self ) = @_;
+    return $self->{explanation} || $self->SUPER::explain();
+}
+
+*__PPIX_ELEM__post_reblessing = \&PPIx::Regexp::Util::__post_rebless_error;
 
 1;
 
@@ -45,7 +67,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -53,7 +77,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
