@@ -1,6 +1,4 @@
-# Cargo cult to try to prevent CPAN from indexing
-package
-PPIx::Regexp::Token::GroupType::Atomic_Script_Run;
+package PPIx::Regexp::Token::GroupType::Atomic_Script_Run;
 
 use 5.006;
 
@@ -11,23 +9,22 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.073';
+our $VERSION = '0.084';
 
-{
-    my $expl = 'All characters must be in same script, atomic version';
+use constant EXPL => 'All characters must be in same script, atomic version';
 
-    __PACKAGE__->__setup_class( {
-	    '*atomic_script_run:'	=> {
-		expl	=> $expl,
-		intro	=> '5.027009',
-	    },
-	    '*asr:'	=> {
-		expl	=> $expl,
-		intro	=> '5.027009',
-	    },
-	},
-    );
-}
+use constant DEF => {
+    '*atomic_script_run:'	=> {
+	expl	=> EXPL,
+	intro	=> '5.027009',
+    },
+    '*asr:'	=> {
+	expl	=> EXPL,
+	intro	=> '5.027009',
+    },
+};
+
+__PACKAGE__->__setup_class();
 
 1;
 
@@ -67,7 +64,9 @@ superclass.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -75,7 +74,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2020 by Thomas R. Wyant, III
+Copyright (C) 2018-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
