@@ -37,7 +37,7 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.073';
+our $VERSION = '0.084';
 
 sub __match_setup {
     my ( undef, $tokenizer ) = @_;	# Invocant unused
@@ -45,19 +45,19 @@ sub __match_setup {
     return;
 }
 
-__PACKAGE__->__setup_class(
-    {
-	'?'	=> {
-	    expl	=> q<Match one of the following '|'-delimited alternatives>,
-	    intro	=> '5.005',
-	},
+use constant DEF	=> {
+    '?'	=> {
+	expl	=> q<Match one of the following '|'-delimited alternatives>,
+	intro	=> '5.005',
     },
+};
+
+__PACKAGE__->__setup_class(
     {
 	suffix	=> '(',
     },
 );
 
-
 1;
 
 __END__
@@ -65,7 +65,9 @@ __END__
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
+L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -73,7 +75,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 by Thomas R. Wyant, III
+Copyright (C) 2009-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
